About
=====

This plugin is a CAT software for the Plover realtime stenography
engine.

Installation
============

This plugin is available from Plover’s plugin manager

Then launch Plover and select Plover Cat from the tools

License
=======

This plugin is licensed under MIT.

Icon made by `Freepik`_ from `www.flaticon.com`_ is licensed by `CC 3.0
BY`_.

.. _Freepik: http://www.freepik.com/
.. _www.flaticon.com: http://www.flaticon.com/
.. _CC 3.0 BY: http://creativecommons.org/licenses/by/3.0/
